Struct BlockingStream

struct BlockingStream<S: Stream + Unpin> { ... }

An iterator which blocks on values from a stream until they become available.

Implementations

impl<S: Stream + Unpin> BlockingStream<S>

fn into_inner(self: Self) -> S

Convert this BlockingStream into the inner Stream type.

impl<I> IntoIterator for BlockingStream<S>

fn into_iter(self: Self) -> I

impl<P, T> Receiver for BlockingStream<S>

impl<S> Freeze for BlockingStream<S>

impl<S> RefUnwindSafe for BlockingStream<S>

impl<S> Send for BlockingStream<S>

impl<S> Sync for BlockingStream<S>

impl<S> Unpin for BlockingStream<S>

impl<S> UnsafeUnpin for BlockingStream<S>

impl<S> UnwindSafe for BlockingStream<S>

impl<S: $crate::fmt::Debug + Stream + Unpin> Debug for BlockingStream<S>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S: Stream + Unpin> Deref for BlockingStream<S>

fn deref(self: &Self) -> &<Self as >::Target

impl<S: Stream + Unpin> DerefMut for BlockingStream<S>

fn deref_mut(self: &mut Self) -> &mut <Self as >::Target

impl<S: Stream + Unpin> Iterator for BlockingStream<S>

fn next(self: &mut Self) -> Option<<Self as >::Item>
fn size_hint(self: &Self) -> (usize, Option<usize>)

impl<T> Any for BlockingStream<S>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for BlockingStream<S>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for BlockingStream<S>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for BlockingStream<S>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for BlockingStream<S>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for BlockingStream<S>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for BlockingStream<S>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>